package com.vpn.fastestvpnservice.screens

import android.content.res.Configuration
import android.util.Log
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.gestures.detectTapGestures
import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.ClickableText
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Done
import androidx.compose.material.icons.filled.DoneOutline
import androidx.compose.material.icons.filled.Email
import androidx.compose.material.icons.filled.Lock
import androidx.compose.material.icons.filled.Visibility
import androidx.compose.material.icons.filled.VisibilityOff
import androidx.compose.material.icons.outlined.Visibility
import androidx.compose.material.icons.sharp.Visibility
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.ExperimentalComposeUiApi
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.paint
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.platform.LocalSoftwareKeyboardController
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.vectorResource
import androidx.compose.ui.text.AnnotatedString
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.text.style.LineHeightStyle
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import androidx.navigation.compose.rememberNavController
import com.vpn.fastestvpnservice.R
import com.vpn.fastestvpnservice.sealedClass.Screen

@OptIn(ExperimentalComposeUiApi::class)
@Composable
fun SignUp(navHostController: NavHostController) {
    val keyboardController = LocalSoftwareKeyboardController.current
    val focusManager = LocalFocusManager.current


    Box(
        modifier = Modifier
            .paint(
                painter = painterResource(id = R.drawable.bg_img3),
                contentScale = ContentScale.FillBounds)
//            .background(
//                if (isSystemInDarkTheme()) Color.Black
//                else Color.Transparent
//            )
            .fillMaxSize()
            .pointerInput(Unit) {
                detectTapGestures {
                    focusManager.clearFocus()
                    keyboardController?.hide()
                }
            }
        ,
//        contentAlignment = Alignment.Center

    ) {
        Column (
            modifier = Modifier
                .fillMaxHeight()
                .fillMaxWidth()
            ,
            verticalArrangement = Arrangement.Top,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {


            Spacer(modifier = Modifier.height(50.dp))

            IconButton(
                onClick = {
                    navHostController.popBackStack()
                },
                modifier = Modifier
                    .padding(start = 16.dp, top = 25.dp)
                    .align(Alignment.Start)
            )
            {
                Icon(painter = painterResource(
                    id = R.drawable.back_arrow3x),
                    contentDescription = "Back Button",
                    tint = colorResource(id = R.color.white),
                    modifier = Modifier
                        .height(36.dp)
                        .width(36.dp)
                        .align(Alignment.Start),
                )
            }
            Spacer(modifier = Modifier.height(44.dp))

            Image(
                painter = painterResource(id = R.drawable.fastestapp_logo3x),
                contentDescription = "FastestVPN",
                modifier = Modifier
                    .size(75.dp, 102.dp)
                    .background(Color.Transparent)
                    .padding(top = 0.dp),
            )
            Spacer(modifier = Modifier.height(50.dp))
            Text(
                modifier = Modifier
                    .padding(start = 15.dp)
                    .align(Alignment.Start)
                ,
                fontSize = 28.sp,
                fontWeight = FontWeight.Medium,
                text = "Hello There!",
                color = Color.White,
            )
            Text(
                modifier = Modifier
                    .padding(start = 15.dp)
                    .align(Alignment.Start),
                fontSize = 14.sp,
                fontWeight = FontWeight.Normal,
                text = "Please login to your account.",
                color = colorResource(id = R.color.light_grey),
            )
            Spacer(modifier = Modifier.height(20.dp))

            var textChanged by remember { mutableStateOf("") }


            TextField(
                value = textChanged,
                onValueChange = {
                    textChanged = it
                },

                textStyle = TextStyle(
                    fontSize = 20.sp,
                    color = colorResource(id = R.color.white),

                    ),
                modifier = Modifier
                    .padding(start = 15.dp, end = 15.dp, top = 10.dp)
                    .align(Alignment.Start)
                    .fillMaxWidth()
                    .height(60.dp)
                    .border(
                        1.dp,
                        color = colorResource(id = R.color.white),
                        shape = RoundedCornerShape(16.dp)
                    ),

//                placeholder = {
//                    Text(text = "Enter email address",
//                        color = colorResource(id = R.color.white),
//                        fontSize = 14.sp,
//                    )
//                },
                label = {
                    Text(text = "Email",
                        style = TextStyle(
                            colorResource(id = R.color.white),
                            fontSize = 12.sp
                        )
                    )
                },
                leadingIcon = {
                    Icon(
                        painter = painterResource(id = R.drawable.sms3x),
                        contentDescription = "Email Logo",
                        tint = colorResource(id = R.color.white),
                        modifier = Modifier
                            .size(24.dp, 24.dp)
                    )
                },
                maxLines = 1,
                colors = TextFieldDefaults.colors(
                    focusedLabelColor = Color.Blue,
                    unfocusedContainerColor = colorResource(id = R.color.transparent),
                    focusedContainerColor = colorResource(id = R.color.transparent),
                    focusedIndicatorColor = colorResource(id = R.color.transparent),
                    disabledIndicatorColor = colorResource(id = R.color.transparent),
                    unfocusedIndicatorColor = colorResource(id = R.color.transparent),
                    cursorColor = colorResource(id = R.color.white)
                ),
                keyboardOptions = KeyboardOptions(
                    keyboardType = KeyboardType.Email,
                    imeAction = ImeAction.Done
                ),
                keyboardActions = KeyboardActions(
                    onDone = {
                        focusManager.clearFocus()
                        keyboardController?.hide()
                    }
                ),

                )

            Spacer(modifier = Modifier.height(20.dp))

            var passwordChanged by remember { mutableStateOf("") }
            var passwordVisible by remember { mutableStateOf(false) }

            TextField(
                value = passwordChanged,
                onValueChange = {
                    Log.d("onClick_test", "onValueChange -> ")
                    passwordChanged = it
                },

                textStyle = TextStyle(
                    fontSize = 20.sp,
                    color = colorResource(id = R.color.white),

                    ),
                modifier = Modifier
                    .padding(start = 15.dp, end = 15.dp)
                    .align(Alignment.Start)
                    .fillMaxWidth()
                    .height(60.dp)
                    .border(
                        1.dp,
                        color = colorResource(id = R.color.grey_password_field),
                        shape = RoundedCornerShape(16.dp)
                    )
                    .background(color = colorResource(id = R.color.transparent)),

                shape = RoundedCornerShape(15.dp),
//                placeholder = {
//                    Text(text = "Enter password",
//                        color = colorResource(id = R.color.white))
//                },
                label = {
                    Text(text = "Password",
                        style = TextStyle(
                            colorResource(id = R.color.white),
                            fontSize = 16.sp
                        )
                    )
                },
                leadingIcon = {
                    Icon(
                        painter = painterResource(id = R.drawable.lock3x),
                        contentDescription = "Password Logo",
                        tint = colorResource(id = R.color.white),
                        modifier = Modifier
                            .size(24.dp, 24.dp)
                    )
                },
                maxLines = 1,
                colors = TextFieldDefaults.colors(
                    focusedLabelColor = Color.Blue,
                    unfocusedContainerColor = colorResource(id = R.color.grey_password_field),
                    focusedContainerColor = colorResource(id = R.color.grey_password_field),
                    focusedIndicatorColor = colorResource(id = R.color.transparent),
                    disabledIndicatorColor = colorResource(id = R.color.transparent),
                    unfocusedIndicatorColor = colorResource(id = R.color.transparent),
                    cursorColor = colorResource(id = R.color.white)
                ),
                keyboardOptions = KeyboardOptions(
                    keyboardType = KeyboardType.Password,
                    imeAction = ImeAction.Done
                ),
                keyboardActions = KeyboardActions(
                    onDone = {
                        focusManager.clearFocus()
                        keyboardController?.hide()
                    }
                ),
                visualTransformation =
                if (passwordVisible) VisualTransformation.None
                else PasswordVisualTransformation(),

                trailingIcon = {
                    Log.d("onClick_test", "trailingIcon -> ")

//                    val image
//                            = if (passwordVisible) Icons.Filled.Visibility
//                    else Icons.Filled.VisibilityOff

                    val description = if (passwordVisible) "Hide Password"
                    else "Show Password"

                    IconButton(onClick = {
                        passwordVisible = !passwordVisible
                    })
                    {
                        if (passwordVisible) {
                            Icon(
                                imageVector = Icons.Outlined.Visibility,
                                contentDescription = description,
                                tint = colorResource(id = R.color.white),
                                modifier = Modifier.size(24.dp)
                            )
                        }
                        else {
                            Icon(
                                painter = painterResource(id = R.drawable.eye_slash3x),
                                contentDescription = description,
                                tint = colorResource(id = R.color.white),
                                modifier = Modifier.size(24.dp)
                            )
                        }

                    }
                }
            )

            Spacer(modifier = Modifier.height(15.dp))

            Row (
                modifier = Modifier
                    .padding(start = 15.dp, top = 16.dp)
                    .fillMaxWidth(),
            ){

                Icon(
                    painter = painterResource(id = R.drawable.tick_square3x),
                    contentDescription = "Logo",
                    tint = colorResource(id = R.color.white),
                    modifier = Modifier.size(24.dp, 24.dp)
                )
                Text(
                    modifier = Modifier
                        .padding(start = 15.dp),
                    fontSize = 15.sp,
                    fontStyle = FontStyle.Normal,
                    text = "By creating your account, you agree to",
                    color = colorResource(id = R.color.white),
                )
            }

            Spacer(modifier = Modifier.height(0.dp))

            Row (
                modifier = Modifier
                    .padding(start = 15.dp)
                    .fillMaxWidth(),
            ){

                Icon(
                    painter = painterResource(id = R.drawable.tick_square3x),
                    contentDescription = "Logo",
                    tint = colorResource(id = R.color.transparent),
                    modifier = Modifier.size(24.dp),
                )
                Text(
                    modifier = Modifier
                        .padding(start = 15.dp),
                    fontSize = 15.sp,
                    fontStyle = FontStyle.Normal,
                    text = "Terms & Conditions",
                    color = colorResource(id = R.color.yellow_text),
                )
            }

        }

        Button(
            onClick = {
                Log.d("test_button", "onClick")
            },
            modifier = Modifier
                .padding(
                    start = 15.dp, end = 15.dp,
                    bottom = 100.dp
                )
                .align(Alignment.BottomCenter)
                .background(colorResource(id = R.color.transparent))
                .fillMaxWidth()
                .height(60.dp),
            shape = RoundedCornerShape(15.dp),
//            border = BorderStroke(25.dp, colorResource(id = R.color.black)),
            colors = ButtonDefaults.buttonColors(
                contentColor = colorResource(id = R.color.light_blue),
                containerColor = colorResource(id = R.color.white),
            ),
        )
        {
            Text(text = "Sign Up",
                style = TextStyle(
                    fontSize = 18.sp,
                    color = colorResource(id = R.color.blue_text),
                    fontWeight = FontWeight.Medium
                ),

                )
        }

        Row (
            modifier = Modifier
                .align(Alignment.BottomCenter)
                .padding(40.dp),
        ){
            Text(
                modifier = Modifier
                    .padding(0.dp),
                fontSize = 15.sp,
                fontWeight = FontWeight.Normal,
                fontStyle = FontStyle.Normal,
                text = "Already have an account? ",
                color = Color.White,
            )
            ClickableText(
                onClick = {
                    navHostController.popBackStack()

                    if (navHostController.currentDestination?.id != null &&
                        navHostController.currentDestination?.route != null){
                        Log.d("test_signup", "From Sign In -> id = " + navHostController.currentDestination?.id
                                + " route = " + navHostController.currentDestination?.route
                        )
                    }
                    else {
                        Log.d("test_signup", "From Sign Up -> id = " + navHostController.currentDestination?.id
                                + " route = " + navHostController.currentDestination?.route
                        )
                        navHostController.navigate(Screen.Login.route)
                    }

                },
                modifier = Modifier
                    .padding(0.dp),
                style = TextStyle(
                    fontSize = 15.sp,
                    fontStyle = FontStyle.Normal,
                    color = colorResource(id = R.color.yellow),
                ),
                text = AnnotatedString(" Sign In"),
            )
        }
    }
}

@Preview
@Composable
fun SignUpPreview() {
    SignUp(rememberNavController())
}

@Preview(uiMode = Configuration.UI_MODE_NIGHT_YES)
@Composable
fun SignUpPreviewDark() {
    SignUp(rememberNavController())
}