package com.vpn.fastestvpnservice.screens.bottomNavBarScreens

import android.content.res.Configuration
import android.util.Log
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.gestures.detectTapGestures
import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.BoxScope
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.ColumnScope
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.Logout
import androidx.compose.material.icons.filled.AccountCircle
import androidx.compose.material.icons.filled.Delete
import androidx.compose.material.icons.filled.Favorite
import androidx.compose.material.icons.filled.Lock
import androidx.compose.material.icons.filled.Logout
import androidx.compose.material.icons.filled.MonetizationOn
import androidx.compose.material3.AlertDialog
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.CompositionLocalProvider
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.runtime.staticCompositionLocalOf
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.ColorFilter
import androidx.compose.ui.graphics.painter.Painter
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.TextUnit
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.window.DialogProperties
import androidx.navigation.NavHostController
import androidx.navigation.compose.rememberNavController
import com.vpn.fastestvpnservice.R
import com.vpn.fastestvpnservice.sealedClass.Screen

//var LocalLoggedOut = staticCompositionLocalOf<Boolean> { false }

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun Account(navHostController: NavHostController) {
    var isLoggedOut by remember { mutableStateOf(false) }
    var isDelete by remember { mutableStateOf(false) }

    Box(modifier = Modifier
        .background(MaterialTheme.colorScheme.background)
        .fillMaxSize()
//        contentAlignment = Alignment.Center

    ) {
        Column(
            verticalArrangement = Arrangement.Top,
            horizontalAlignment = Alignment.Start,
            modifier = Modifier
                .padding(start = 16.dp, end = 24.dp)
                .fillMaxSize()
        ) {
            Spacer(modifier = Modifier.height(60.dp))
            AddTextAccount(
                text = "Account",
                size = 28.sp,
                color = MaterialTheme.colorScheme.primary
            )
            AddRowAccount("Email:", "asif@yopmail.com")
            AddRowAccount("Product:", "Lifetime Plan")
            AddRowAccount("Account Status:", "Active")

            Surface(
                modifier = Modifier
                    .padding(top = 24.dp, bottom = 0.dp)
                    .height(1.dp)
                    .fillMaxWidth(),
                color = colorResource(id = R.color.gray_icon)
            ) {}

            AddRowAccountIcon(
                icon = painterResource(id = R.drawable.subscription3x),
                text = "Upgrade Subscription",
                onClick = {
                    navHostController.navigate(
                        Screen.Subscription.route
                    )
                }
            )
            AddRowAccountIcon(
                icon = painterResource(id = R.drawable.fav3x),
                text = "Favorite Servers",
                onClick = {
                    navHostController.navigate(
                        Screen.FavoriteServers.route
                    )
                }
            )
            AddRowAccountIcon(
                icon = painterResource(id = R.drawable.lock3x),
                text = "Change Password",
                onClick = {
                    navHostController.navigate(
                        Screen.ChangePassword.route
                    )
                }
            )
            AddRowAccountIcon(
                icon = painterResource(id = R.drawable.delete3x),
                text = "Delete Account",
                onClick = {
                    isDelete = true
                    Log.d("islogoutClicked?", "isDelete Yes")
                }
            )
            AddRowAccountIcon(
                icon = painterResource(id = R.drawable.logout3x),
                text = "Logout",
                onClick = {
                    isLoggedOut = true
                    Log.d("islogoutClicked?", "Yes")
                }
            )
        }

        if (isLoggedOut) {
            Log.d("islogoutClicked", "isLoggedOut$isLoggedOut")

            AlertDialog(
                onDismissRequest = { isLoggedOut = false },
                properties = DialogProperties(),
                modifier = Modifier
                    .fillMaxWidth()
                    .height(228.dp)
                ) {
                LogoutDialog("Logout Account",
                    "Are you sure to logout the account?",
                    onCancel = { isLoggedOut = false }
                    )
            }
        }

        if (isDelete) {
            Log.d("islogoutClicked", "isDelete$isDelete")

            AlertDialog(
                onDismissRequest = { isDelete = false },
                properties = DialogProperties(),
                modifier = Modifier
                    .fillMaxWidth()
                    .height(228.dp)
            ) {
                LogoutDialog("Delete Account",
                    "Are you sure to delete the account?",
                    onCancel = { isDelete = false }
                    )
            }
        }

    }
}

@Composable
fun ColumnScope.AddTextAccount(text: String, size: TextUnit, color: Color) {
    Text(
        text = text,
        style = TextStyle(
            fontSize = size,
            color = color,
            textAlign = TextAlign.Center,
            fontStyle = FontStyle.Normal,
            fontWeight = FontWeight.Medium,
        ),
    )
}

@Composable
fun ColumnScope.AddRowAccount(title: String, subTitle: String) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(top = 16.dp)
            .background(Color.Transparent)
            .height(18.dp),
        horizontalArrangement = Arrangement.SpaceBetween,
        verticalAlignment = Alignment.CenterVertically
    ) {
        Surface(
            modifier = Modifier.padding(start = 0.dp),
            color = Color.Transparent
        ) {
            Text(text = title,
                style = TextStyle(
                    color = MaterialTheme.colorScheme.primary,
                    fontSize = 14.sp,
                    fontStyle = FontStyle.Normal,
                    fontWeight = FontWeight.Medium
                ),
                maxLines = 1,
                modifier = Modifier
                    .padding(start = 10.dp, end = 0.dp)
                    .weight(1f)
            )
        }
//        Spacer(modifier = Modifier.weight(1f))

        Surface(
            modifier = Modifier
                .padding(start = 0.dp)
                .align(Alignment.CenterVertically),
            color = Color.Transparent

        ) {
            Text(text = subTitle,
                style = TextStyle(
                    color = MaterialTheme.colorScheme.primary,
                    fontSize = 14.sp,
                    fontStyle = FontStyle.Normal,
                    fontWeight = FontWeight.Medium,
                    textAlign = TextAlign.Right,
                ),
                maxLines = 1,
                modifier = Modifier
                    .padding(start = 0.dp, end = 0.dp)
                    .weight(1f)
                    .alpha(0.6F)
            )
        }

    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ColumnScope.AddRowAccountIcon(
    icon: Painter,
    text: String,
    onClick : () -> Unit
) {

    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(top = 33.dp)
            .background(Color.Transparent)
            .height(30.dp)
            .pointerInput(Unit) {
                detectTapGestures {
                    onClick()
                }
            },
        horizontalArrangement = Arrangement.Start,
        verticalAlignment = Alignment.CenterVertically
    ) {
        Surface(
            modifier = Modifier.padding(start = 0.dp),
            color = Color.Transparent
        ) {
            Image(
                painter = icon,
                contentDescription = "World",
                modifier = Modifier
                    .padding(start = 0.dp)
                    .size(24.dp)
                    .weight(1f),
                colorFilter = ColorFilter.tint(MaterialTheme.colorScheme.primary)
            )
        }
        Surface(
            modifier = Modifier.padding(start = 0.dp),
            color = Color.Transparent
        ) {
            Text(text = text,
                style = TextStyle(
                    color = MaterialTheme.colorScheme.primary,
                    fontSize = 16.sp,
                    fontStyle = FontStyle.Normal,
                    fontWeight = FontWeight.Medium
                ),
                maxLines = 2,
                modifier = Modifier
                    .padding(start = 20.dp, end = 0.dp)
                    .weight(1f)
            )
        }
        Spacer(modifier = Modifier.weight(1f))
        Surface(
            modifier = Modifier
                .padding(start = 15.dp)
                .align(Alignment.CenterVertically),
            color = Color.Transparent
        ) {
            Image(
                painter = painterResource(id = R.drawable.frontarrow3x),
                contentDescription = "Front_Arrow",
                modifier = Modifier
                    .padding(start = 0.dp, end = 5.dp)
                    .size(10.dp, 18.dp)
                    .weight(1f),
                colorFilter = ColorFilter.tint(MaterialTheme.colorScheme.primary)
            )
        }


    }


}

@Composable
fun BoxScope.LogoutDialog(
    title: String,
    desc: String,
    onCancel : () -> Unit
) {
    Surface(
        color = colorResource(id = R.color.white),
        modifier = Modifier
            .background(Color.Transparent)
            .fillMaxWidth()
        ,
        shape = RoundedCornerShape(18.dp)
    ) {
        Column(
            verticalArrangement = Arrangement.Top,
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier
                .background(MaterialTheme.colorScheme.onPrimary)
        ) {
            Log.d("islogoutClicked", "AlertDialog")

            Text(text = title,
                style = TextStyle(
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center,
                    fontWeight = FontWeight.Medium,
                    color = MaterialTheme.colorScheme.primary
                ),
                modifier = Modifier.padding(top = 45.dp)
            )
            Text(text = desc,
                style = TextStyle(
                    fontSize = 18.sp,
                    textAlign = TextAlign.Center,
                    color = MaterialTheme.colorScheme.primary,
                    lineHeight = 30.sp
                ),
                maxLines = 2,
                modifier = Modifier.padding(top = 26.dp)
            )
            Row (
                modifier = Modifier
                    .padding(top = 34.dp),
                horizontalArrangement = Arrangement.SpaceBetween,
                verticalAlignment = Alignment.Bottom
            ) {
                Button(
                    onClick = {
                        Log.d("test_button", "onClick Send Code")
                        onCancel()
//                                    navHostController.popBackStack()
//                                    navHostController.navigate(Screen.Login.route)
                    },
                    modifier = Modifier
                        .padding(
                            start = 15.dp, end = 5.dp,
                            bottom = 0.dp, top = 0.dp
                        )
                        .background(colorResource(id = R.color.transparent))
                        .weight(1F)
                        .height(52.dp),

                    shape = RoundedCornerShape(15.dp),
                    colors = ButtonDefaults.buttonColors(
                        contentColor = colorResource(id = R.color.white),
                        containerColor = colorResource(id = R.color.light_blue),
                    ),
                )
                {
                    Text(text = "No", fontSize = 20.sp)
                    Log.d("test_button", "RowScope")
                }

                Button(
                    onClick = {
                        Log.d("test_button", "onClick Send Code")
//                                    navHostController.popBackStack()
//                                    navHostController.navigate(Screen.SignUp.route)
                    },
                    modifier = Modifier
                        .padding(
                            start = 5.dp, end = 15.dp,
                            bottom = 0.dp, top = 0.dp
                        )
                        .background(colorResource(id = R.color.transparent))
                        .weight(1F)
                        .height(52.dp),
                    shape = RoundedCornerShape(15.dp),
                    colors = ButtonDefaults.buttonColors(
                        contentColor = colorResource(id = R.color.white),
                        containerColor = colorResource(id = R.color.red),
                    ),
//                                border = BorderStroke(2.dp,
//                                    colorResource(id = R.color.gray_icon))
                )
                {
                    Text(text = "Yes", fontSize = 20.sp)
                    Log.d("test_button", "RowScope")
                }
            }
        }

    }
}

@Preview
@Composable
fun AccountPreview() {
    Account(rememberNavController())
}

@Preview(uiMode = Configuration.UI_MODE_NIGHT_YES)
@Composable
fun AccountPreviewDark() {
    Account(rememberNavController())
}